'use client'

import { useState } from 'react';
import Image from 'next/image';

import * as style from './copy.css';
import copy_image_dark from './copy_image_dark.svg';
import copy_image_light from './copy_image_light.svg';
import copied_image_dark from './copied_image_dark.svg';
import copied_image_light from './copied_image_light.svg';

export default function Copy({ className, text, show_text }: { className?: string, text: string, show_text?: boolean }) {
	const [copied, set_copied] = useState(false);
	function make_copy_text(text: string) {
		return () => {
			navigator.clipboard.writeText(text);
			set_copied(true);
			setTimeout(() => { set_copied(false); }, 2000);
		};
	}
	return <div className={`${style.copy} ${className ?? ''}`}>
		<button onClick={make_copy_text(text)} className={`${style.copy_button}`}>
			{copied ? <>
				<Image
					className={style.copied_image_dark}
					src={copied_image_dark}
					alt="Copied"
				/>
				<Image
					className={style.copied_image_light}
					src={copied_image_light}
					alt="Copied"
				/>
			</> :
			<>
				<Image
					className={style.copy_image_dark}
					src={copy_image_dark}
					alt="Copy"
				/>
				<Image
					className={style.copy_image_light}
					src={copy_image_light}
					alt="Copy"
				/>
			</>}
		</button>
		{show_text ? <p className={style.copy_text}>{text}</p> : <></>}
	</div>;
}
